CONNECT TO TLMA%

CREATE PROCEDURE ADM.CREATE_TABLE_IF_NOT_EXISTS_TMP(in SCHEMA_NAME char(40), in TABLE_NAME char(40), in COLUMNS_DEFINITION varchar(920))
	BEGIN
		DECLARE numRecords INT DEFAULT 0;
		DECLARE stmt VARCHAR(1000);

		SELECT COUNT(*) INTO numRecords
		FROM SYSCAT.TABLES 
		WHERE TABSCHEMA = SCHEMA_NAME AND TABNAME = TABLE_NAME;
			
		SET stmt = 'CREATE TABLE ' CONCAT SCHEMA_NAME CONCAT '.' CONCAT TABLE_NAME CONCAT '(' CONCAT COLUMNS_DEFINITION CONCAT ')';
		IF numRecords = 0 THEN
			PREPARE prep_stmt FROM stmt;
			EXECUTE prep_stmt;
		END IF;
	END%

CALL ADM.CREATE_TABLE_IF_NOT_EXISTS_TMP(
	'ADM',
	'UPGRADED_COMPONENTS',
	'COMPONENT_GUID VARCHAR(40) NOT NULL, BUNDLED_RELEASE_GUID VARCHAR(40) NOT NULL, NEW_COMPONENT_GUID VARCHAR(40) NOT NULL, TARGET_RELEASE_GUID VARCHAR(40) NOT NULL'
)%

DROP PROCEDURE ADM.CREATE_TABLE_IF_NOT_EXISTS_TMP%

grant select, insert, delete, update, alter on ADM.UPGRADED_COMPONENTS to user TLMSRV%

comment on table ADM.UPGRADED_COMPONENTS is
    'The table stores information about currently bundled components and target bundling after upgrade of components'%
comment on column ADM.UPGRADED_COMPONENTS.COMPONENT_GUID is
    'GUID of the upgraded component'%
comment on column ADM.UPGRADED_COMPONENTS.BUNDLED_RELEASE_GUID is
    'GUID of the release bundled with the component'%
comment on column ADM.UPGRADED_COMPONENTS.NEW_COMPONENT_GUID is
    'GUID of the component after upgrade'%
comment on column ADM.UPGRADED_COMPONENTS.TARGET_RELEASE_GUID is
    'GUID of the release that the new component should be bundled'%
    
INSERT INTO lic.control_values(
	control_key, 
	control_value, 
	control_value_type, 
	control_value_enum,
	control_hidden,
	control_units)
SELECT 'preserveBundlingForUpgraded', 'false', 2, 'false, true', 1, 'true/false'
FROM sysibm.sysdummy1 
WHERE NOT EXISTS (SELECT 1 FROM lic.control_values WHERE control_key = 'preserveBundlingForUpgraded')%    
    
INSERT INTO adm.rule_type(id, rule_id, score, display_name) VALUES (7, 'COMP_UPGRADED_RULE', 100, 'Upgraded Components')%
    
DISCONNECT CURRENT%